@@ -18,7 +18,8 @@ setClass("dat", representation(psi.df = "matrix", psi.weight = "matrix",
 	lowcon = "vector", datafile = "character", getX = "logical",
 	clpType = "character", clpequspecBD = "list", compnames = "vector", 
 	getXsuper = "logical", usecompnames0 = "logical", 
-	usecompnamesequ = "logical", autoclp0 = "list", cohcol = "numeric"), 
+	usecompnamesequ = "logical", autoclp0 = "list", cohcol = "numeric",
+        weightList = "list"), 
         prototype = list(psi.df = matrix(), psi.weight = matrix(), 
             x = vector(), nt = integer(), x2 = vector(), nl = integer(), 
             C2 = matrix(), E2 = matrix(), sigma = numeric(), 
@@ -36,8 +37,9 @@ setClass("dat", representation(psi.df = "matrix", psi.weight = "matrix",
 	    clinde = list(), chinde = list(), highcon = vector(), 
 	    lowcon = vector(), datafile = "", getX = FALSE, 
 	    clpType = "", clpequspecBD = list(), compnames = vector(),
-	    getXsuper = FALSE, usecompnames0 = FALSE, 
-	    usecompnamesequ = FALSE, autoclp0 = list(), cohcol = 0))
+	    getXsuper = FALSE, usecompnames0 = FALSE,  
+	    usecompnamesequ = FALSE, autoclp0 = list(), cohcol = 0,
+            weightList = list()))
 
 
 setClass("kin", representation("dat", kinpar = "vector", specpar =
@@ -50,7 +52,11 @@ dispmu = "logical", dispmufun = "character", anipar = "vector", parmu
 = "list", ncolc = "vector", kinscal = "vector", kmatfit = "array",
 cohspec = "list", coh = "vector", wavedep = "logical", lambdac =
 "numeric", speckin2 = "list", usekin2 = "logical", kinpar2 = "vector",
-kin2scal = "vector"), prototype = list( kinpar = vector(), seqmod =
+kin2scal = "vector", amplitudes = "vector", streakT = "numeric", 
+streak="logical", doublegaus = "logical", fixedkmat="logical",
+kinscalspecialspec ="list", kinscalspecial = "list",
+lightregimespec = "list"),
+         prototype = list( kinpar = vector(), seqmod =
 TRUE, irf = FALSE, mirf = FALSE, measured_irf = vector(), convalg = 1,
 cohirf = vector(), irffun = "gaus", anispec = list(), irfpar =
 vector(), dispmu = FALSE, dispmufun = "poly", parmu = list(), anipar =
@@ -59,7 +65,10 @@ partau = vector(), posk = FALSE, disptau = FALSE, fullk = FALSE,
 kmat = array(), jvec = vector(), ncolc = vector(), kinscal = vector(),
 kmatfit = array(), cohspec = list(), coh = vector(), wavedep =
 logical(), lambdac = numeric(), speckin2 = list(), usekin2 = FALSE,
-kinpar2 = vector(), kin2scal = vector() ))
+kinpar2 = vector(), kin2scal = vector(), amplitudes = vector(), 
+streakT = 0, streak = FALSE, doublegaus = FALSE, fixedkmat=FALSE,
+           kinscalspecialspec = list(),  kinscalspecial = list(),
+           lightregimespec = list() ))
 
 setClass("mass", 
 representation("kin", 
@@ -67,27 +76,30 @@ peakpar = "list",
 amplitudes = "vector", 
 peakfunct = "character",
 lzerofile = "character", 
-lextracomp = "logical", 
-extracomp = "list"),
+extracomp = "logical", 
+shift = "vector"),
 prototype = list( 
 peakpar = list(), 
 peakfunct = "expmodgaus", 
 lzerofile = "", 
 amplitudes = vector(), 
 getX=TRUE, 
-lextracomp = FALSE,
-extracomp = list())
+extracomp = TRUE,
+shift = vector() )
 )
 
 setClass("spec", representation("dat", clpequ = "vector", 
         specpar = "list", specfun = "character", specref = "numeric", 
         specCon = "list", ncole = "vector", specdisp = "logical", 
         specdisppar = "list", specdispindex = "vector", nupow = "numeric", 
-	timedep = "logical", parmufunc = "character"), 
+        timedep = "logical", parmufunc = "character"), 
         prototype = list(specpar = list(), specfun = "gaus", 
-            specCon = list(), ncole = vector(), specdisp = FALSE, 
-            specdisppar = list(), specdispindex = vector(), specref =
-	    numeric(), nupow = 5, clpequ = vector(), 
-	    timedep = FALSE, parmufunc = "poly")) 
+          specCon = list(), ncole = vector(), specdisp = FALSE, 
+          specdisppar = list(), specdispindex = vector(), specref =
+          numeric(), nupow = 5, clpequ = vector(), 
+          timedep = FALSE, parmufunc = "poly")) 
+
+setClass("amp", representation("dat", amps = "list"),
+         prototype = list(amps = list(), clpdep = FALSE))
 
 
